# Acoustic Boundary Element Method (abem)

AcousticBEM is a small library and example programs for solving the acoustic
Helmholtz equation using the Boundary Element Method. The library is a
re-implementation of the core components of Stephen Kirkup's ABEM Fortran
library and its example programs. 
The original Fortran code and the book "The Boundary Element Method in
Acoustics" are available on his website: 
<http://www.boundary-element-method.com/>.

